==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.contact.vcard.impl/src/com/openexchange/contact/vcard/impl/internal/VCardExceptionUtils.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.contact.vcard.impl.internal;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map.Entry;
import com.openexchange.exception.OXException;
import ezvcard.ValidationWarnings;
import ezvcard.Warning;
import ezvcard.property.VCardProperty;

/**
 * {@link VCardExceptionUtils}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class VCardExceptionUtils {

    public static List<OXException> getParserWarnings(List<String> parserWarnings) {
        if (null != parserWarnings && 0 < parserWarnings.size()) {
            List<OXException> warnings = new ArrayList<OXException>();
            for (String warning : parserWarnings) {
                warnings.add(VCardExceptionCodes.PARSER_ERROR.create(warning));
            }
            return warnings;
        }
        return Collections.emptyList();
    }

    public static List<OXException> getValidationWarnings(ValidationWarnings validationWarnings) {
        if (null != validationWarnings && false == validationWarnings.isEmpty()) {
            List<OXException> warnings = new ArrayList<OXException>();
            for (Entry<VCardProperty, List<Warning>> entry : validationWarnings) {
                VCardProperty property = entry.getKey();
                List<Warning> propViolations = entry.getValue();
                String propertyName = null != property ? property.getClass().getSimpleName() : "";
                if (null != propViolations && 0 < propViolations.size()) {
                    for (Warning propViolation : propViolations) {
                        warnings.add(VCardExceptionCodes.VALIDATION_FAILED.create(propertyName, propViolation.getMessage(), propViolation.getCode()));
                    }
                }
            }
            return warnings;
        }
        return Collections.emptyList();
    }

}

==> open-xchange-core_7.10.4.orig.tar.bz2: open-xchange-core-7.10.4/com.openexchange.contact.vcard.impl/src/com/openexchange/contact/vcard/impl/internal/VCardExceptionUtils.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.contact.vcard.impl.internal;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map.Entry;
import com.openexchange.exception.OXException;
import ezvcard.ValidationWarning;
import ezvcard.ValidationWarnings;
import ezvcard.io.ParseWarning;
import ezvcard.property.VCardProperty;

/**
 * {@link VCardExceptionUtils}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class VCardExceptionUtils {

    public static List<OXException> getParserWarnings(List<ParseWarning> parserWarnings) {
        if (null != parserWarnings && 0 < parserWarnings.size()) {
            List<OXException> warnings = new ArrayList<OXException>();
            for (ParseWarning warning : parserWarnings) {
                warnings.add(VCardExceptionCodes.PARSER_ERROR.create(warning.toString()));
            }
            return warnings;
        }
        return Collections.emptyList();
    }

    public static List<OXException> getValidationWarnings(ValidationWarnings validationWarnings) {
        if (null != validationWarnings && false == validationWarnings.isEmpty()) {
            List<OXException> warnings = new ArrayList<OXException>();
            for (Entry<VCardProperty, List<ValidationWarning>> entry : validationWarnings) {
                VCardProperty property = entry.getKey();
                List<ValidationWarning> propViolations = entry.getValue();
                String propertyName = null != property ? property.getClass().getSimpleName() : "";
                if (null != propViolations && 0 < propViolations.size()) {
                    for (ValidationWarning propViolation : propViolations) {
                        warnings.add(VCardExceptionCodes.VALIDATION_FAILED.create(propertyName, propViolation.getMessage(), propViolation.getCode()));
                    }
                }
            }
            return warnings;
        }
        return Collections.emptyList();
    }

}
